@@ -15,7 +15,7 @@ class Wire():
     async def __call__(self, scope: dict, receive, send) -> None:
         req = Request(scope, receive, send)
         try:
-            if req.path.startswith(self.static.route):
+            if self.static is not None and req.path.startswith(self.static.route):
                 content, typ = self.static.provide(req.path)
                 resp = Response(content, headers={"content-type": typ})
                 await resp(scope, receive, send)
@@ -35,27 +35,35 @@ class Wire():
             await response(scope, receive, send)
 
     def get(self, path: str):
-        def wrapper(handler: typing.Union[typing.Callable, typing.Awaitable]) -> typing.Union[typing.Callable, typing.Awaitable]:
+        def wrapper(handler: typing.Union[typing.Callable, typing.Awaitable]) -> typing.Union[
+            typing.Callable, typing.Awaitable]:
             self.router.add_route(path, handler, "get")
             return handler
+
         return wrapper
 
     def post(self, path: str):
-        def wrapper(handler: typing.Union[typing.Callable, typing.Awaitable]) -> typing.Union[typing.Callable, typing.Awaitable]:
+        def wrapper(handler: typing.Union[typing.Callable, typing.Awaitable]) -> typing.Union[
+            typing.Callable, typing.Awaitable]:
             self.router.add_route(path, handler, "post")
             return handler
+
         return wrapper
 
     def put(self, path: str):
-        def wrapper(handler: typing.Union[typing.Callable, typing.Awaitable]) -> typing.Union[typing.Callable, typing.Awaitable]:
+        def wrapper(handler: typing.Union[typing.Callable, typing.Awaitable]) -> typing.Union[
+            typing.Callable, typing.Awaitable]:
             self.router.add_route(path, handler, "put")
             return handler
+
         return wrapper
 
     def delete(self, path: str):
-        def wrapper(handler: typing.Union[typing.Callable, typing.Awaitable]) -> typing.Union[typing.Callable, typing.Awaitable]:
+        def wrapper(handler: typing.Union[typing.Callable, typing.Awaitable]) -> typing.Union[
+            typing.Callable, typing.Awaitable]:
             self.router.add_route(path, handler, "delete")
             return handler
+
         return wrapper
 
     def mount(self, plugin: typing.Union[Group, StaticFiles], prefix: str = None):
@@ -65,7 +73,8 @@ class Wire():
             return True
         if not prefix.startswith("/"):
             raise Exception(f"Invalid prefix for router {plugin}")
-        for route in plugin.routes:
-            self.router.add_route(prefix + route[0], route[1], route[2])
-        print(f"Mounted router: {plugin}")
-        return True
\ No newline at end of file
+        else:
+            for route in plugin.routes:
+                self.router.add_route(prefix + route[0], route[1], route[2])
+            print(f"Mounted router: {plugin}")
+            return True
