@@ -10,7 +10,8 @@ class Response:
     media_type = None
     charset = "utf-8"
 
-    def __init__(self, content: typing.Any, status: typing.Union[int, HttpStatusCode] = 200, headers: dict = None, media_type: str = None) -> None:
+    def __init__(self, content: typing.Any, status: typing.Union[int, HttpStatusCode] = 200, headers: dict = None,
+                 media_type: str = None) -> None:
         self.status = status if isinstance(status, int) else status.value
         self.content: typing.Any = content
         if media_type:
@@ -50,6 +51,7 @@ class Response:
 class HTMLResponse(Response):
     media_type = "text/html"
 
+
 class JsonResponse(Response):
     media_type = "application/json"
 
